﻿using System;
using System.Xml.Serialization;

namespace TestProject
{
    /// <summary>
    /// 사람
    /// </summary>
    [Serializable]
    public class Person
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Enumeration
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 연락처 - ContactMethod

        /// <summary>
        /// 연락처
        /// </summary>
        public enum ContactMethod
        {
            /// <summary>
            /// 우편
            /// </summary>
            [XmlEnum("SnailMail")]
            Post,

            /// <summary>
            /// 전화
            /// </summary>
            [XmlEnum("Telephone")]
            Phone,

            /// <summary>
            /// 메일
            /// </summary>
            [XmlEnum("Email")]
            Email
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 이름
        /// </summary>
        [XmlAttributeAttribute("GivenName")]
        public string FirstName;

        /// <summary>
        /// 성
        /// </summary>
        [XmlAttributeAttribute("FamilyName")]
        public string LastName;

        /// <summary>
        /// 도로
        /// </summary>
        [XmlElement("StreetAddress")]
        public string Street;

        /// <summary>
        /// 선호 연락처
        /// </summary>
        [XmlElement("ContactMethod")]
        public ContactMethod PreferredMethod;

        /// <summary>
        /// 도시
        /// </summary>
        public string City;

        /// <summary>
        /// 주
        /// </summary>
        public string State;

        /// <summary>
        /// 우편 번호
        /// </summary>
        [XmlIgnore]
        public string Zip;

        /// <summary>
        /// 전화 배열
        /// </summary>
        [XmlArray("PhoneNumbers"), XmlArrayItem("PhoneNum")]
        public string[] PhoneArray = new string[1];

        /// <summary>
        /// 메일 배열
        /// </summary>
        [XmlArray("EmailAddresses")]
        public string[] EmailArray = new string[1];

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - Person()

        /// <summary>
        /// 생성자
        /// </summary>
        public Person()
        {
        }

        #endregion
        #region 생성자 - Person(firstName, lastName, street, city, state, zip, phone1, phone2, email1, email2, contactMethod)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="firstName">이름</param>
        /// <param name="lastName">성</param>
        /// <param name="street">거리</param>
        /// <param name="city">도시</param>
        /// <param name="state">주</param>
        /// <param name="zip">우편 번호</param>
        /// <param name="phone1">전화 1</param>
        /// <param name="phone2">전화 2</param>
        /// <param name="email1">메일 1</param>
        /// <param name="email2">메일 2</param>
        /// <param name="contactMethod">연락처</param>
        public Person(string firstName, string lastName, string street, string city, string state, string zip, string phone1, string phone2, string email1, string email2, ContactMethod contactMethod)
        {
            FirstName       = firstName;
            LastName        = lastName;
            Street          = street;
            City            = city;
            State           = state;
            Zip             = zip;
            PhoneArray      = new string[] { phone1, phone2 };
            EmailArray      = new string[] { email1, email2 };
            PreferredMethod = contactMethod;
        }

        #endregion
    }
}